@@ -31,6 +31,10 @@
 #include <windows.h>
 #endif
 
+#ifdef HAVE_PYTHON
+#include <Python.h>
+#endif //HAVE_PYTHON
+
 #include <QString>
 #include <QTimer>
 #include <QMutex>
@@ -38,6 +42,9 @@
 #include <QtAlgorithms>
 #include <QChar>
 #include <QPair>
+#include <QReadLocker>
+#include <QWriteLocker>
+#include <QReadWriteLock>
 
 #include "fqterm.h"
 #include "common.h"
@@ -73,6 +80,8 @@ const QString  FQTermSession::endOfUrl[] = {
 };
 
 FQTermSession::FQTermSession(FQTermConfig *config, FQTermParam param) {
+  reconnectRetry_ = 0;
+  scriptListener_ = NULL;
   param_ = param;
   termBuffer_ = new FQTermBuffer(param_.numColumns_,
                                  param_.numRows_,
@@ -81,20 +90,20 @@ FQTermSession::FQTermSession(FQTermConfig *config, FQTermParam param) {
 
   if (param.protocolType_ == 0) {
     telnet_ = new FQTermTelnet(param_.virtualTermType_.toLatin1(),
-                               param_.numRows_, param_.numColumns_, param.protocolType_ );
+                               param_.numRows_, param_.numColumns_, param.protocolType_, param.hostType_ );
   } else if (param.protocolType_ == 3) {
     telnet_ = new FQTermTelnet(param_.virtualTermType_.toLatin1(),
-      param_.numRows_, param_.numColumns_, param.protocolType_ );
+      param_.numRows_, param_.numColumns_, param.protocolType_, param.hostType_ );
   } else {
 #if defined(_NO_SSH_COMPILED)
     QMessageBox::warning(this, "sorry",
                          "SSH support is not compiled, "
                          "FQTerm can only use Telnet!");
     telnet_ = new FQTermTelnet(param_.virtualTermType_.toUtf8(),
-                               param_.numRows_, param_.numColumns_, param.protocolType_ );
+                               param_.numRows_, param_.numColumns_, param.protocolType_, param.hostType_ );
 #else
     telnet_ = new FQTermTelnet(param_.virtualTermType_.toUtf8(),
-                               param_.numRows_, param_.numColumns_, param.protocolType_ ,
+                               param_.numRows_, param_.numColumns_, param.protocolType_ , param.hostType_ , 
                                param_.sshUserName_.toUtf8(),
                                param_.sshPassword_.toUtf8());
 #endif
@@ -121,12 +130,9 @@ FQTermSession::FQTermSession(FQTermConfig *config, FQTermParam param) {
 
   idleTimer_ = new QTimer;
   autoReplyTimer_ = new QTimer;
-  reconnectTimer_ = new QTimer;
 
-  acThread_ = new ArticleCopyThread(*this, waitCondition_);
+  acThread_ = new ArticleCopyThread(*this, waitCondition_, bufferWriteLock_);
 
-  FQ_VERIFY(connect(reconnectTimer_, SIGNAL(timeout()),
-                    this, SLOT(reconnect())));
   FQ_VERIFY(connect(decoder_, SIGNAL(mouseMode(bool)),
                     this, SLOT(setMouseMode(bool))));
   FQ_VERIFY(connect(telnet_, SIGNAL(readyRead(int, int)),
@@ -162,7 +168,6 @@ FQTermSession::FQTermSession(FQTermConfig *config, FQTermParam param) {
 FQTermSession::~FQTermSession() {
   delete idleTimer_;
   delete autoReplyTimer_;
-  delete reconnectTimer_;
   delete acThread_;
   delete termBuffer_;
   delete telnet_;
@@ -179,11 +184,12 @@ void FQTermSession::setScreenStart(int nStart) {
 }
 
 bool FQTermSession::setCursorPos(const QPoint &pt, QRect &rc) {
-  QRect rectOld = getSelectRect();
+  QRect rectOld = getMenuRect();
 
   cursorPoint_ = pt;
 
-  QRect rectNew = getSelectRect();
+  detectMenuRect();
+  QRect rectNew = getMenuRect();
 
   rc = rectOld | rectNew;
 
@@ -318,7 +324,7 @@ FQTermSession::CursorType FQTermSession::getCursorType(const QPoint &pt) {
     return kNormal;
   }
 
-  QRect rc = getSelectRect();
+  QRect rc = getMenuRect();
   CursorType nCursorType = kNormal;
   switch (pageState_) {
     case Undefined:  // not recognized
@@ -404,9 +410,9 @@ FQTermSession::CursorType FQTermSession::getCursorType(const QPoint &pt) {
   return nCursorType;
 }
 
-bool FQTermSession::isSelected(int line) {
+bool FQTermSession::isSelectedMenu(int line) {
   // TODO: possible performance issue
-  QRect rect = getSelectRect();
+  QRect rect = getMenuRect();
 
   // nothing selected
   if (rect.isNull()) {
@@ -416,9 +422,9 @@ bool FQTermSession::isSelected(int line) {
   return line >= rect.bottom() && line <= rect.top();
 }
 
-bool FQTermSession::isSelected(const QPoint &pt) {
+bool FQTermSession::isSelectedMenu(const QPoint &pt) {
   // TODO: possible performance issue
-  QRect rect = getSelectRect();
+  QRect rect = getMenuRect();
 
   // nothing selected
   if (rect.isNull()) {
@@ -435,10 +441,22 @@ FQTermSession::PageState FQTermSession::getPageState() {
 char FQTermSession::getMenuChar() {
   return menuChar_;
 }
-//getSelectRect:
-QRect FQTermSession::getSelectRect() {
-  QRect rect(0, 0, 0, 0);
 
+void FQTermSession::setMenuRect(int row, int col, int len) {
+  menuRect_ = QRect(col, row, len, 1);
+}
+
+QRect FQTermSession::detectMenuRect() {
+  QRect rect(0, 0, 0, 0);
+  menuRect_ = rect;
+  if (scriptListener_) 
+  {
+    bool res = scriptListener_->postQtScriptCallback(SFN_DETECT_MENU);
+  #ifdef HAVE_PYTHON
+    res = scriptListener_->postPythonCallback(SFN_DETECT_MENU, Py_BuildValue("l", scriptListener_->windowID())) || res;
+  #endif  //HAVE_PYTHON
+    if (res) return menuRect_;
+  }
   // current screen scrolled
   if (screenStartLineNumber_ !=
       (termBuffer_->getNumLines() - termBuffer_->getNumRows())) {
@@ -567,12 +585,12 @@ QRect FQTermSession::getSelectRect() {
     default:
       break;
   }
-
+  menuRect_ = rect;
   return rect;
 }
 
 bool FQTermSession::isIllChar(char ch) {
-  static char illChars[] = ",;'\"()[]<>^";
+  static char illChars[] = ";'\"[]<>^";
   return ch > '~' || ch < '!' || strchr(illChars, ch) != NULL;
 }
 
@@ -813,6 +831,15 @@ void FQTermSession::setAntiIdle(bool antiIdle) {
   }
 }
 
+void FQTermSession::setAutoReconnect(bool autoReconnect) {
+  param_.isAutoReconnect_ = autoReconnect;
+  reconnectRetry_ = 0;
+  if (autoReconnect && !isConnected_) {
+    reconnectProcess();
+  }
+}
+
+
 void FQTermSession::autoReplyMessage() {
   if (autoReplyTimer_->isActive()) {
     autoReplyTimer_->stop();
@@ -820,7 +847,14 @@ void FQTermSession::autoReplyMessage() {
   if (pageState_ != Message) {
     return;
   }
-
+  if (scriptListener_) 
+  {
+    bool res = scriptListener_->postQtScriptCallback(SFN_AUTO_REPLY);
+#ifdef HAVE_PYTHON
+    res = scriptListener_->postPythonCallback(SFN_AUTO_REPLY, Py_BuildValue("l", scriptListener_->windowID())) || res;
+#endif  //HAVE_PYTHON
+    if (res) return;
+  }
   QByteArray cstrTmp = param_.replyKeyCombination_.toLocal8Bit();
   QByteArray cstr = parseString(cstrTmp.isEmpty() ? QByteArray("^Z"): cstrTmp);
   //cstr += m_param.m_strAutoReply.toLocal8Bit();
@@ -875,18 +909,14 @@ QByteArray FQTermSession::parseString(const QByteArray &cstr, int *len) {
 void FQTermSession::reconnect() {
   if (!isConnected_) {
     telnet_->connectHost(param_.hostAddress_, param_.port_);
+    reconnectRetry_++;
   }
 }
 
 void FQTermSession::reconnectProcess() {
-  static int retry = 0;
-  if (retry < param_.retryTimes_ || param_.retryTimes_ == -1) {
-    if (param_.reconnectInterval_ <= 0) {
-      reconnect();
-    } else {
-      reconnectTimer_->start(param_.reconnectInterval_ *1000);
-    }
-    retry++;
+  if (!isConnected_ && param_.isAutoReconnect_ && (reconnectRetry_ < param_.retryTimes_ || param_.retryTimes_ == -1)) {
+    int interval = param_.reconnectInterval_ <= 0 ? 0 : param_.reconnectInterval_ * 1000;
+    QTimer::singleShot(interval, this, SLOT(reconnect()));
   }
 }
 
@@ -914,7 +944,7 @@ void FQTermSession::doAutoLogin() {
 
   // smth ignore continous input, so sleep 1 sec :)
 #if defined(_OS_WIN32_) || defined(Q_OS_WIN32)
-  Sleep(1);
+  Sleep(1000);
 #else
   sleep(1);
 #endif
@@ -945,8 +975,13 @@ void FQTermSession::readReady(int size, int raw_size) {
       int last_size = telnet_data_.size();
       telnet_data_.resize(last_size + size);
       telnet_->read(&telnet_data_[0] + last_size, size);
-
-      int processed = decoder_->decode(&telnet_data_[0], telnet_data_.size());
+      int processed = 0;
+      {
+        while (!bufferWriteLock_.tryLockForWrite()) {}
+        //QWriteLocker locker(&bufferWriteLock_);
+        processed = decoder_->decode(&telnet_data_[0], telnet_data_.size());
+        bufferWriteLock_.unlock();
+      }
       telnet_data_.erase(telnet_data_.begin(), telnet_data_.begin() + processed);
     }
 
@@ -983,7 +1018,7 @@ void FQTermSession::readReady(int size, int raw_size) {
     strText = strText.trimmed();
 
     if (termBuffer_->getCaretRow() == termBuffer_->getNumRows() - 1
-        && termBuffer_->getCaretColumn() >= strText.length() - 1) {
+        && termBuffer_->getCaretColumn() >= (strText.length() - 1) / 2) {
       waitCondition_.wakeAll();
     }
 
@@ -996,31 +1031,33 @@ void FQTermSession::readReady(int size, int raw_size) {
       emit startAlert();
       emit bellReceived();
 
-      if (isAutoReply()) {
+      bool bellConsumed = false;
+      if (scriptListener_) {
+        bellConsumed = scriptListener_->postQtScriptCallback(SFN_ON_BELL);
 #ifdef HAVE_PYTHON
-        if (!pythonCallback("autoReply", Py_BuildValue("(l)", this))) {
+        bellConsumed = scriptListener_->postPythonCallback(SFN_ON_BELL, Py_BuildValue("l", scriptListener_->windowID())) || bellConsumed;
 #endif
+      }
+
+      if (isAutoReply() && !bellConsumed) {
           // TODO: save messages
           if (isIdling_) {
             autoReplyMessage();
           } else {
             autoReplyTimer_->start(param_.maxIdleSeconds_ *1000 / 2);
           }
-#ifdef HAVE_PYTHON
-        }
-#endif
       }
     }
 
     // set page state
     detectPageState();
-
-    emit sessionUpdated();
-
+    if (scriptListener_) {
+      scriptListener_->postQtScriptCallback(SFN_DATA_EVENT);
 #ifdef HAVE_PYTHON
-    // python
-    pythonCallback("dataEvent", Py_BuildValue("(l)", this));
+      scriptListener_->postPythonCallback(SFN_DATA_EVENT, Py_BuildValue("l", scriptListener_->windowID()));
 #endif
+    }
+    emit sessionUpdated();
   }
 
   if (zmodem_->transferstate == transferstop) {
@@ -1028,24 +1065,6 @@ void FQTermSession::readReady(int size, int raw_size) {
   }
 }
 
-QByteArray FQTermSession::stripWhitespace(const QByteArray &cstr) {
-  QString cstrText = QString::fromLatin1(cstr);
-
-#if (QT_VERSION>=300)
-  int pos = cstrText.lastIndexOf(QRegExp("[\\S]"));
-#else
-  int pos = cstrText.lastIndexOf(QRegExp("[^\\s]"));
-#endif
-
-  if (pos == -1) {
-    cstrText = "";
-  } else {
-    cstrText.truncate(pos + 1);
-  }
-
-  return cstrText.toLatin1();
-}
-
 /* 0-left 1-middle 2-right 3-relsase 4/5-wheel
  *
  */
@@ -1133,6 +1152,7 @@ void FQTermSession::changeTelnetState(int state) {
       break;
     case TSHOSTCONNECTED:
       isConnected_ = true;
+      reconnectRetry_ = 0;
       if (param_.isAutoLogin_) {
         isTelnetLogining_ = true;
       }
@@ -1239,6 +1259,19 @@ QByteArray FQTermSession::unicode2bbs_smart(const QString &text) {
       strTmp = U2B(text);
     }
     break;
+  case FQTERM_ENCODING_HKSCS:
+    if (FQTermPref::getInstance()->imeEncodingID_ == FQTERM_ENCODING_GBK)
+    {
+      strTmp = U2G(text);
+      char* tmp = encodingConverter_.G2B(strTmp, strTmp.length());
+      strTmp = tmp;
+      delete []tmp;
+    }
+    else
+    {
+      strTmp = U2H(text);
+    }
+    break;
   case FQTERM_ENCODING_UTF8:
     strTmp = U2U8(text);
     break;
@@ -1247,63 +1280,6 @@ QByteArray FQTermSession::unicode2bbs_smart(const QString &text) {
   return strTmp;
 }
 
-#ifdef HAVE_PYTHON
-bool FQTermSession::pythonCallback(const QString &func, PyObject *pArgs) {
-  if (!isPythonScriptLoaded_) {
-    Py_DECREF(pArgs);
-    return false;
-  };
-
-  bool done = false;
-  // get the global lock
-  PyEval_AcquireLock();
-  // get a reference to the PyInterpreterState
-
-  //Python thread references
-  extern PyThreadState *mainThreadState;
-
-  PyInterpreterState *mainInterpreterState = mainThreadState->interp;
-  // create a thread state object for this thread
-  PyThreadState *myThreadState = PyThreadState_New(mainInterpreterState);
-  PyThreadState_Swap(myThreadState);
-
-  PyObject *pF = PyString_FromString(func.toLatin1());
-  PyObject *pFunc = PyDict_GetItem(pythonDict_, pF);
-  Py_DECREF(pF);
-
-  if (pFunc && PyCallable_Check(pFunc)) {
-    PyObject *pValue = PyObject_CallObject(pFunc, pArgs);
-    Py_DECREF(pArgs);
-    if (pValue != NULL) {
-      done = true;
-      Py_DECREF(pValue);
-    } else {
-      // TODO: fixme.
-      // QMessageBox::warning(this, "Python script error", getException());
-    }
-  } else {
-    PyErr_Print();
-    FQ_TRACE("session", 0) << "Cannot find python callback function: "
-                           << func;
-  }
-
-  // swap my thread state out of the interpreter
-  PyThreadState_Swap(NULL);
-  // clear out any cruft from thread state object
-  PyThreadState_Clear(myThreadState);
-  // delete my thread state object
-  PyThreadState_Delete(myThreadState);
-  // release the lock
-  PyEval_ReleaseLock();
-
-  if (func == "autoReply") {
-    // TODO: fixme
-    // paveViewMessage_->display("You have messages", PageViewMessage::Info, 0);
-  }
-
-  return done;
-}
-#endif //HAVE_PYTHON
 
 void FQTermSession::onIdle() {
   // do as autoreply when it is enabled
@@ -1315,11 +1291,14 @@ void FQTermSession::onIdle() {
 
   isIdling_ = true;
   // system script can handle that
+  if (scriptListener_) {
+    bool res = scriptListener_->postQtScriptCallback(SFN_ANTI_IDLE);
 #ifdef HAVE_PYTHON
-  if (pythonCallback("antiIdle", Py_BuildValue("(l)", this))) {
-    return ;
-  }
+    res = scriptListener_->postPythonCallback(SFN_ANTI_IDLE, Py_BuildValue("l", scriptListener_->windowID())) || res;
 #endif
+    if (res)
+      return;
+  }
   // the default function
   int length;
   QByteArray cstr = parseString(param_.antiIdleMessage_.toLocal8Bit(), &length);
@@ -1368,9 +1347,6 @@ void FQTermSession::connectHost(const QString &hostName, quint16 portNumber) {
 
 void FQTermSession::close() {
   telnet_->close();
-  if (reconnectTimer_->isActive()) {
-    reconnectTimer_->stop();
-  }
   finalizeConnection();
 }
 
@@ -1478,15 +1454,26 @@ void FQTermSession::onSSHAuthOK() {
     telnet_->windowSizeChanged(param_.numColumns_, param_.numRows_);
 }
 
+void FQTermSession::updateSetting( const FQTermParam& p ) {
+  bool toggleAutoReconnect = (p.isAutoReconnect_ != param_.isAutoReconnect_);
+  param_ = p;
+  setTermSize(p.numColumns_, p.numRows_);
+  setAntiIdle(isAntiIdle());
+  if (toggleAutoReconnect)
+    setAutoReconnect(param_.isAutoReconnect_);
+}
+
 ArticleCopyThread::ArticleCopyThread(
-    FQTermSession &bbs, QWaitCondition &waitCondition)
+    FQTermSession &bbs, QWaitCondition &waitCondition, QReadWriteLock &bufferLock)
     : session_(bbs),
       waitCondition_(waitCondition),
-      mutex_(new QMutex()) {
+      lock_(bufferLock) {
+    FQ_VERIFY(connect(this, SIGNAL(writeSession(const QString&)), 
+                      &session_, SLOT(handleInput(const QString&)), 
+                      Qt::QueuedConnection));
 }
 
 ArticleCopyThread::~ArticleCopyThread() {
-  delete mutex_;
 }
 
 static void removeTrailSpace(QString &line) {
@@ -1531,7 +1518,7 @@ static std::pair<int, int> ParseLastLine(QString str) {
 
 
 void ArticleCopyThread::run() {
-  mutex_->lock();
+  QReadLocker locker(&lock_);
 
   typedef std::vector<QString> Page;
   const FQTermBuffer *buffer = session_.getBuffer();;
@@ -1542,8 +1529,9 @@ void ArticleCopyThread::run() {
   buffer->getTextLineInTerm(buffer->getNumRows() - 1)->getAllPlainText(firstPageLastLine);
   if (firstPageLastLine.indexOf("%") != -1) {
     MultiPage = true;
-    session_.write("e", 1);
-    if (!waitCondition_.wait(mutex_, 10000)) {
+    //session_.write("e", 1);
+    emit writeSession("e");
+    if (!waitCondition_.wait(&lock_, 10000)) {
       emit articleCopied(DAE_TIMEOUT, "");
       return;
     }
@@ -1559,8 +1547,9 @@ void ArticleCopyThread::run() {
       buffer->getTextLineInTerm(i - range.first)->getAllPlainText(strTemp);
       page[i - 1] = strTemp;
     }
-    session_.write("s", 1);
-    if (!waitCondition_.wait(mutex_, 10000)) {
+    //session_.write("s", 1);
+    emit writeSession("s");
+    if (!waitCondition_.wait(&lock_, 10000)) {
       emit articleCopied(DAE_TIMEOUT, "");
       return;
     }
@@ -1595,8 +1584,9 @@ void ArticleCopyThread::run() {
 
 
     // wait for next page.
-    session_.write(" ", 1);
-    if (!waitCondition_.wait(mutex_, 10000)) {
+    //session_.write(" ", 1);
+    emit writeSession(" ");
+    if (!waitCondition_.wait(&lock_, 10000)) {
       emit articleCopied(DAE_TIMEOUT, "");
       break;
     }
@@ -1614,7 +1604,6 @@ void ArticleCopyThread::run() {
 
   //qApp->postEvent(pWin, new QCustomEvent(DAE_FINISH));
   emit articleCopied(DAE_FINISH, articleText);
-  mutex_->unlock();
 }
 
 }  // namespace FQTerm
