@@ -180,11 +180,13 @@ struct fsm_trans FQTermTelnet::substab[] =  {
  *------------------------------------------------------------------------
  */
 FQTermTelnet::FQTermTelnet(const QString &strTermType, int rows, int columns,
-                           int protocolType, const char *sshuser, const char *sshpasswd)
+                           int protocolType, int hostType, const char *sshuser, const char *sshpasswd)
     : from_socket(),
       to_ansi(),
       from_ansi(),
-      to_socket() {
+      to_socket(),
+      hostType_(hostType),
+      protocolType_(protocolType) {
   term = new char[21];
   int i;
   for (i = 0; i < 21; i++) {
@@ -209,7 +211,7 @@ FQTermTelnet::FQTermTelnet(const QString &strTermType, int rows, int columns,
 
 #ifndef _NO_SSH_COMPILED
   if (protocolType == 1 || protocolType == 2) {
-    socket = new FQTermSSHSocket(sshuser, sshpasswd);
+    socket = new FQTermSSHSocket(columns, rows, strTermType, sshuser, sshpasswd);
     FQ_VERIFY(connect(socket, SIGNAL(sshAuthOK()),
 		      this, SIGNAL(onSSHAuthOK())));
   } else if (protocolType == 3) {
@@ -334,33 +336,28 @@ void FQTermTelnet::connectHost(const QString &hostname, quint16 portnumber) {
 }
 
 void FQTermTelnet::windowSizeChanged(int x, int y) {
-//    fprintf(stderr, " FQTermTelnet::windowsizechanged 1\n");
   wx = x;
   wy = y;
   if (bConnected) {
-    if (server_sent_do_naws || naws) {
-      QByteArray cmd(9, ' ');
-      cmd[0] = TCIAC;
-      cmd[1] = TCSB;
-      cmd[2] = TONAWS;
-      cmd[3] = ((char)((unsigned short)(wx) >> 8));
-      cmd[4] = ((char)((unsigned short)(wx) &0xff));
-      cmd[5] = ((char)((unsigned short)(wy) >> 8));
-      cmd[6] = ((char)((unsigned short)(wy) &0xff));
-      cmd[7] = TCIAC;
-      cmd[8] = TCSE;
-      socket->writeBlock(cmd);
-      //fprintf(stderr, " FQTermTelnet::windowsizechanged 2\n");
-      naws = 0;
-    } else if (!naws) {
-      naws = 1;
-      QByteArray cmd(3, ' ');
-      cmd[0] = TCIAC;
-      cmd[1] = TCWILL;
-      cmd[2] = TONAWS;
-      socket->writeBlock(cmd);
-      //fprintf(stderr, " FQTermTelnet::windowsizechanged 3\n");
+    if (hostType_ == 1 && (protocolType_ == 1 || protocolType_ == 2)) {
+      //This is a *nix host, with ssh connection.
+      socket->setTermSize(x, y);
+      return;
     }
+    naws = 0;
+
+    QByteArray cmd(10, 0);
+    cmd[0] = (char)TCIAC;
+    cmd[1] = (char)TCSB;
+    cmd[2] = (char)TONAWS;
+    cmd[3] = (char)(short(wx) >> 8);
+    cmd[4] = (char)(short(wx) & 0xff);
+    cmd[5] = (char)(short(wy) >> 8);
+    cmd[6] = (char)(short(wy) & 0xff);
+    cmd[7] = (char)TCIAC;
+    cmd[8] = (char)TCSE;
+    socket->writeBlock(cmd);
+
   }
 }
 
@@ -851,38 +848,32 @@ int FQTermTelnet::will_termtype(int c) {
 }
 
 int FQTermTelnet::will_naws(int c) {
-  if (option_cmd == TCDO) {
-    server_sent_do_naws = 1;
-  }
-  //fprintf(stderr, " FQTermTelnet::will_naws 1\n");
   if (naws) {
-    if (option_cmd != TCDO) {
+    if (option_cmd == TCDO)
       return 0;
-    }
-  } else if (option_cmd == TCDONT) {
+  } else if (option_cmd == TCDONT)
     return 0;
-  }
 
-  if (!naws)
-  {
-      //fprintf(stderr, " FQTermTelnet::will_naws 2\n");
-    putc_down(TCIAC);
+
+  naws = !naws;
+
+  putc_down(TCIAC);
+  if (naws)
     putc_down(TCWILL);
-    putc_down((char)c);
-  }
-  //fprintf(stderr, " FQTermTelnet::will_naws \n");
+  else
+    putc_down(TCWONT);
+  putc_down((char)c);
+
   putc_down(TCIAC);
   putc_down(TCSB);
   putc_down(TONAWS);
   putc_down((char)(short(wx) >> 8));
-  putc_down((char)(short(wx) &0xff));
+  putc_down((char)(short(wx)&0xff));
   putc_down((char)(short(wy) >> 8));
-  putc_down((char)(short(wy) &0xff));
+  putc_down((char)(short(wy)&0xff));
   putc_down(((char)TCIAC));
   putc_down((char)TCSE);
-  putc_down((char)c);
 
-  naws = 0;
   return 0;
 }
 
